@@ -43,6 +43,7 @@ namespace KWin
 {
 
 KWIN_EFFECT(trackmouse, TrackMouseEffect)
+KWIN_EFFECT_SUPPORTED(trackmouse, TrackMouseEffect::supported())
 
 const int STARS = 5;
 const int DIST = 50;
@@ -71,6 +72,11 @@ TrackMouseEffect::~TrackMouseEffect()
     delete texture;
 }
 
+bool TrackMouseEffect::supported()
+{
+    return effects->compositingType() == OpenGLCompositing;
+}
+
 void TrackMouseEffect::reconfigure(ReconfigureFlags)
 {
     KConfigGroup conf = effects->effectConfig("TrackMouse");
